@@ -5,6 +5,7 @@ import getopt
 import os
 import datetime
 import sys
+import plugins
 from random import randint as random
 from server import Server
 
@@ -89,6 +90,8 @@ class BaskitCLI(cmd.Cmd):
         sync                        Handles syncing to/from ramdisk and
                                     persistent storage if ramdisk support is
                                     enabled (disabled by default)
+
+        plugin                      Stuff will go here eventually.....
         '''
     
 
@@ -264,6 +267,20 @@ class BaskitCLI(cmd.Cmd):
             Snapshot(self.server).onecmd('help')
 
 
+    def do_plugin(self, s):
+        '''snapshot
+        Handles all snapshot functions including management of all snapshots.
+        For more information run:
+        
+        snapshot help
+        '''
+        msg = 'type exit to return the main console'
+        if len(s) > 1:
+            plugins.Plugins(self.server).onecmd(s)
+        else:
+            plugins.Plugins(self.server).onecmd('help')
+
+
     def do_sync(self, s):
         '''sync [destination] [world1, [world2, world3]]
         Handles synchronization between the persistent and ramdisk storage.
